/*
 * Copyright (c) 2008-2014 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global NX, Nexus, Ext, Sonatype*/
NX.define('Nexus.ssl.certificate.AddByServerFetch', {
  extend : 'Nexus.ssl.certificate.FetchCertificateView',
  xtype : 'ssl-add-by-server',

  requires : ['Nexus.ssl.Icons'],

  layout : 'anchor',
  windowHeight : 175,
  defaultMsgIcon : 'fetch-from-server',
  defaultMsg : 'Please enter a hostname, hostname:port or a URL to fetch a SSL certificate from.',

  initComponent : function() {
    var self = this;
    self.items = [
      {
        xtype : 'textfield',
        name : 'host',
        style : 'margin: 10px;',
        anchor : '100%',
        // set by 'show smtp cert'
        value : self.host,
        readOnly : self.host !== undefined,
        validator : function(value) {
          value = self.trim(value);
          if ( value && value.length > 0 ) {
            return true;
          }

          return "Please provide a hostname.";
        },
        listeners : {
          afterrender : {
            fn : function(cmp) {
              cmp.focus(false, 100);
            },
            single : true
          },
          specialkey : function(field, evt) {
            switch(evt.getKey()) {
              case evt.RETURN:
              case evt.ENTER:
                self.onLoad();
                break;
            }
          },
          invalid : function() {
            self.buttons[0].disable();
          },
          valid : function() {
            self.buttons[0].enable();
          }
        }
      }
    ];
    self.constructor.superclass.initComponent.apply(self, arguments);
  },

  parseHostString : function(str) {
    if (!str) {
      return [];
    }

    if (str.indexOf(":") === -1) { // neither URL nor host:port
      return [str];
    }

    if (str.indexOf("/") === -1) { // definitely no URL
      return str.split(":");
    }

    var rx = /[^:]*:\/\/([^:\/]*)(:([0-9]*))?/,
        matches = str.match(rx);

    if (matches) {
      return [matches[1], matches[3]];
    }

    return [str];
  },

  fetchPEM : function() {
    var
          self = this,
          url = self.find('name', 'host')[0].getValue(),
          detail = self.parseHostString(url),
          host = detail[0],
          port = detail[1] || 443;

    Ext.Ajax.request({
      url : Sonatype.config.contextPath + '/service/siesta/ssl/certificates',
      method : 'GET',
      params : {
        host : host,
        port : port
      },
      suppressStatus : [400, 404],
      success : function(response) {
        self.showCertificate(Ext.decode(response.responseText));
      },
      failure : function(response) {
        var message = "Could not fetch certificate from host '" + host + ":" + port + "'.<br/>";

        if (response.siestaError) {
          message += response.siestaError.message;
        } else if (response.siestaValidationError) {
          Ext.each(response.siestaValidationError, function(error) {
            message += error.id + ": " + error.message + "<br/>";
          });
        } else {
          message += Sonatype.utils.parseHTMLErrorMessage(response.responseText);
        }

        self.showErrorMessage(message);
      }
    });
  }
});
