/*
 * Copyright (c) 2008-2014 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global define, Ext, Nexus, Sonatype, NX*/
NX.define('Nexus.ssl.repository.CertificateTab', {
  extend : 'Nexus.ssl.AbstractCertificateTab',


  constructor : function(cfg) {
    if (!cfg || !cfg.payload) {
      throw new Error("payload missing: need repository record");
    }

    var
          data = cfg.payload.data,
          settings = {
            frame : true,
            autoScroll : true,
            readOnly : true, // don't want save/cancel buttons
            data : data,
            certRequestParams : {
              repositoryId : data.id
            }
          };

    Ext.apply(cfg, settings);

    this.constructor.superclass.constructor.apply(this, arguments);
  }

}, function() {
  Sonatype.Events.addListener('repositoryViewInit', function(cardPanel, rec) {
    var sp = Sonatype.lib.Permissions, newRecord, isProxyRepo;

    // Check whether record is new or received from Nexus
    // (GridViewer convention for new records: id starts with 'new_')
    newRecord = rec.id && rec.id.indexOf('new_') === 0;
    isProxyRepo = rec.data.repoType === 'proxy';

    if (!newRecord && isProxyRepo &&
          (
                // The "list repos" resource has different DTOs than the one creating a repository.
                // When you get a repo record via list, it has remoteUri but not remoteStorage,
                // when the record is created (but not 'refreshed' from the server) it's the other way around.
                ( rec.data.remoteUri && rec.data.remoteUri.startsWith('https') ) ||
                ( rec.data.remoteStorage && rec.data.remoteStorage.remoteStorageUrl && rec.data.remoteStorage.remoteStorageUrl.startsWith('https') )
          ) &&
          ( sp.checkPermission('nexus:repositories', sp.CREATE) || sp.checkPermission('nexus:repositories', sp.DELETE)
                || sp.checkPermission('nexus:repositories', sp.EDIT) )) {
      cardPanel.add(new Nexus.ssl.repository.CertificateTab({
        tabTitle : 'SSL',
        name : 'ssl',
        payload : rec
      }));
    }
  });
});
