/*
 * Copyright (c) 2008-2014 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global NX, Ext, Nexus*/

/**
 * Staging profile data store.
 *
 * @since staging 2.3
 */
NX.define('Nexus.staging.profile.ProfileStore', {
    extend: 'Ext.data.JsonStore',

    /**
     * Flag if group profiles have been detected.
     *
     * @type {boolean}
     */
    hasGroups: false,

    constructor: function (config) {
        var self = this,
            config = config || {};

        // customize store configuration
        Ext.apply(config, {
            url: Sonatype.config.servicePath + '/staging/profiles',
            root: 'data',
            id: 'id',

            fields: [
                { name: 'resourceURI' },
                { name: 'id' },
                { name: 'name' },
                { name: 'promotionTargetRepository' },
                { name: 'mode' },
                { name: 'repositoryType' }
            ],

            sortInfo: {
                field: 'name',
                direction: 'ASC'
            }
        });

        // initialize parent class with customized configuration
        self.constructor.superclass.constructor.call(self, config);

        // Detect if there are any group profiles on load
        self.on('load', function(store, records) {
            var i;
            self.hasGroups = false;
            for (i = 0; i < records.length; i = i + 1) {
                if (records[i].get('mode') === 'GROUP') {
                    self.hasGroups = true;
                    break;
                }
            }
        });

        // Reset if a failure occurs
        self.on('loadexception', function() {
            self.hasGroups = false;
        })
    },

    /**
     * @public
     */
    nameForId: function(id) {
        var record = this.getById(id);
        if (record) {
            return record.get('name');
        }
        else {
            this.logDebug('Missing profile for ID:', id);
            // use id as name
            return id;
        }
    }
});