/*
 * Copyright (c) 2008-2014 Sonatype, Inc.
 *
 * All rights reserved. Includes the third-party code listed at http://links.sonatype.com/products/nexus/pro/attributions
 * Sonatype and Sonatype Nexus are trademarks of Sonatype, Inc. Apache Maven is a trademark of the Apache Foundation.
 * M2Eclipse is a trademark of the Eclipse Foundation. All other trademarks are the property of their respective owners.
 */
/*global NX, Ext, Nexus*/

/**
 * Support to render activity details into the message panel.
 *
 * @since staging 2.3
 */
NX.define('Nexus.staging.repository.activity.ActivityDetail', {
    extend: 'Nexus.staging.repository.activity.DetailSupport',

    statics: {
        /**
         * @protected
         */
        activityTpl: NX.create('Ext.XTemplate',
            '<div>',
                '{[ this.header(values) ]}',
                '<div class="nx-staging-repository-ActivityView-messagePanel-body">',
                    '{[ this.details(values) ]}',
                '</div>',
            '</div>',
            {
                compiled: true,

                header: function (values) {
                    var detail = values.detail;

                    return Nexus.staging.repository.activity.DetailSupport.headerTpl.apply({
                        title: 'Activity: ' + detail.getTitle(),
                        icon: detail.getIcon().variant('x32').img, // use larger 32x32 icons if we have them
                        timestamp: this.renderDuration(values)
                    });
                },

                renderDuration: function (values) {
                    var activity = values.data,
                        elapsed;

                    // FIXME: Format something more reasonable than 'ms'
                    if (!activity.stopped) {
                        elapsed = activity.started.getElapsed(/*now*/);
                        return '(Running) ' + elapsed + 'ms';
                    }

                    elapsed = activity.started.getElapsed(activity.stopped);
                    return '' + elapsed + 'ms';
                },

                details: function (values) {
                    var activity = values.data,
                        properties = [];

                    properties.push(
                        { name: 'started', value: Nexus.staging.repository.activity.DetailSupport.timestamp(activity.started) }
                    );

                    if (activity.startedByUserId) {
                        properties.push(
                            { name: 'userId', value: activity.startedByUserId },
                            { name: 'ipAddress', value: activity.startedByIpAddress }
                        );
                    }

                    if (activity.stopped) {
                        properties.push(
                            { name: 'stopped', value: Nexus.staging.repository.activity.DetailSupport.timestamp(activity.stopped) }
                        );
                    }

                    properties.push(
                        { name: 'events', value: activity.events ? activity.events.length : 0 }
                    );

                    return Nexus.staging.repository.activity.DetailSupport.propertiesTpl.apply({
                        properties: properties
                    });
                }
            }
        )
    },

    /**
     * @property
     */
    activity: undefined,

    /**
     * @constructor
     */
    constructor: function (activity) {
        NX.assert(activity, 'Missing activity');
        this.activity = activity;
    },

    /**
     * @override
     */
    getIcon: function () {
        try {
            return Nexus.staging.Icons.forActivityName(this.activity.name);
        }
        catch (e) {
            this.logError('Missing icon for activity: ' + this.activity.name);
            return Nexus.staging.Icons.get('bug');
        }
    },

    /**
     * @override
     */
    getTitle: function () {
        return this.activity.name;
    },

    /**
     * @override
     */
    getTemplate: function () {
        return Nexus.staging.repository.activity.ActivityDetail.activityTpl;
    }

});
